==> sui-login-password-reset-1.13.0.tgz: package/lib/components/Form/PasswordResetForm.js <==
// import {Link} from 'react-router-dom'
import { useState } from 'react';
import AtomButton, {
// atomButtonDesigns,
atomButtonShapes, atomButtonSizes } from '@s-ui/react-atom-button';
import MoleculeInputField from '@s-ui/react-molecule-input-field';
import { BASE_CLASS } from './../../config.js';
import useI18n from './../../hooks/useI18n.js';
import LoginButton from './LoginButton.js';
import Notification from './Notification.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
var PasswordResetForm = function PasswordResetForm() {
  var _useState = useState(''),
    email = _useState[0],
    setEmail = _useState[1];
  var _useState2 = useState(false),
    isLoading = _useState2[0],
    setIsLoading = _useState2[1];
  var _useState3 = useState(''),
    errorText = _useState3[0],
    setErrorText = _useState3[1];
  var _useState4 = useState(''),
    notificationText = _useState4[0],
    setNotificationText = _useState4[1];
  var i18n = useI18n();
  var checkIfInputIsEmpty = function checkIfInputIsEmpty(value) {
    var isEmpty = value.length === 0;
    isEmpty ? setErrorText(i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.ERRORS.EMPTY_EMAIL')) : setErrorText('');
    return isEmpty;
  };

  // const checkIfValidMail = value => {
  //   console.log('checkIfValidMail')
  //   return true
  // }

  var handleChange = function handleChange(e) {
    console.log('handleChange');
    var _e$target = e == null ? void 0 : e.target,
      value = _e$target.value;
    setEmail(value);
    checkIfInputIsEmpty(value);
    setIsLoading(false);
  };
  var handleSubmit = function handleSubmit() {
    console.log('handleSubmit: Call to use case');
    setIsLoading(true);

    /* CALL TO USE CASE */
    setNotificationText(i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.SUCCESS.EMAIL_SENDED', {
      email: email
    })); // SUCCESS
    // setNotificationText(i18n.t('LOGIN_CROSS.PASSWORD_RESET.ERRORS.GENERIC_ERRORS')) // FAIL
    // setIsLoading(false)
  };

  var handleResend = function handleResend() {
    console.log('handleResend');
    setNotificationText(i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.SUCCESS.EMAIL_RESEND', {
      email: email
    })); // SUCCESS
  };

  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [notificationText ? /*#__PURE__*/_jsx(Notification, {
      notificationText: notificationText,
      handleResend: handleResend
    }) : null, !notificationText ? /*#__PURE__*/_jsx("div", {
      className: BASE_CLASS + "-formInput",
      children: /*#__PURE__*/_jsx(MoleculeInputField, {
        errorText: errorText,
        id: "email",
        label: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.EMAIL_LABEL'),
        name: "email",
        onChange: handleChange,
        placeholder: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.EMAIL_PLACEHOLDER'),
        size: "l",
        type: "text",
        value: email
      })
    }) : null, /*#__PURE__*/_jsxs("div", {
      className: BASE_CLASS + "-formButtons",
      children: [!notificationText ? /*#__PURE__*/_jsx("div", {
        className: BASE_CLASS + "-formButton",
        children: /*#__PURE__*/_jsx(AtomButton
        // disabled={} // TODO
        , {
          fullWidth: true,
          isLoading: isLoading // TODO
          ,
          onClick: handleSubmit // TODO
          ,
          shape: atomButtonShapes.CIRCULAR,
          size: atomButtonSizes.LARGE,
          children: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.SUBMIT_BUTTON')
        })
      }) : null, /*#__PURE__*/_jsx("div", {
        className: BASE_CLASS + "-formButton",
        children: /*#__PURE__*/_jsx(LoginButton, {})
      })]
    })]
  });
};
PasswordResetForm.displayName = 'PasswordResetForm';
export default PasswordResetForm;

==> sui-login-password-reset-1.16.0.tgz: package/lib/components/Form/PasswordResetForm.js <==
// import {Link} from 'react-router-dom'
import { useState } from 'react';
import AtomButton, {
// atomButtonDesigns,
atomButtonShapes, atomButtonSizes } from '@s-ui/react-atom-button';
import MoleculeInputField from '@s-ui/react-molecule-input-field';
import { BASE_CLASS } from '../../config.js';
import useDomain from '../../hooks/useDomain.js';
import useI18n from '../../hooks/useI18n.js';
import LoginButton from '../Input/LoginButton.js';
import Notification from '../Info/Notification.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
var PasswordResetForm = function PasswordResetForm() {
  var _useState = useState(''),
    email = _useState[0],
    setEmail = _useState[1];
  var _useState2 = useState(false),
    isLoading = _useState2[0],
    setIsLoading = _useState2[1];
  var _useState3 = useState(''),
    errorText = _useState3[0],
    setErrorText = _useState3[1];
  var _useState4 = useState(''),
    notificationText = _useState4[0],
    setNotificationText = _useState4[1];
  var i18n = useI18n();
  var domain = useDomain();
  var checkIfInputIsEmpty = function checkIfInputIsEmpty(value) {
    var isEmpty = value.length === 0;
    isEmpty ? setErrorText(i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.ERRORS.EMPTY_EMAIL')) : setErrorText('');
    return isEmpty;
  };
  var handleChange = function handleChange(e) {
    console.log('handleChange');
    var _e$target = e == null ? void 0 : e.target,
      value = _e$target.value;
    setEmail(value);
    checkIfInputIsEmpty(value);
    setIsLoading(false);
  };
  var handleSubmit = function handleSubmit() {
    console.log('handleSubmit: Call to use case');
    setIsLoading(true);
    domain.get('reset_password_use_case').execute({
      email: email
    }).then(function (_ref) {
      var error = _ref[0],
        result = _ref[1];
      if (error) {
        console.log('error', error);
        setNotificationText(i18n.t('LOGIN_CROSS.PASSWORD_RESET.ERRORS.GENERIC_ERROR')); // FAIL
        setIsLoading(false);
      } else {
        console.log('result', result);
        setNotificationText(i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.SUCCESS.EMAIL_SENDED', {
          email: email
        })); // SUCCESS
        setIsLoading(false);
      }
    });
  };
  var handleResend = function handleResend() {
    console.log('handleResend');
    setNotificationText(i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.SUCCESS.EMAIL_RESEND', {
      email: email
    })); // SUCCESS
  };

  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [notificationText ? /*#__PURE__*/_jsx(Notification, {
      notificationText: notificationText,
      handleResend: handleResend
    }) : null, !notificationText ? /*#__PURE__*/_jsx("div", {
      className: BASE_CLASS + "-formInput",
      children: /*#__PURE__*/_jsx(MoleculeInputField, {
        errorText: errorText,
        id: "email",
        label: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.EMAIL_LABEL'),
        name: "email",
        onChange: handleChange,
        placeholder: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.EMAIL_PLACEHOLDER'),
        size: "l",
        type: "text",
        value: email
      })
    }) : null, /*#__PURE__*/_jsxs("div", {
      className: BASE_CLASS + "-formButtons",
      children: [!notificationText ? /*#__PURE__*/_jsx("div", {
        className: BASE_CLASS + "-formButton",
        children: /*#__PURE__*/_jsx(AtomButton
        // disabled={} // TODO
        , {
          fullWidth: true,
          isLoading: isLoading // TODO
          ,
          onClick: handleSubmit // TODO
          ,
          shape: atomButtonShapes.CIRCULAR,
          size: atomButtonSizes.LARGE,
          children: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.SUBMIT_BUTTON')
        })
      }) : null, /*#__PURE__*/_jsx("div", {
        className: BASE_CLASS + "-formButton",
        children: /*#__PURE__*/_jsx(LoginButton, {})
      })]
    })]
  });
};
PasswordResetForm.displayName = 'PasswordResetForm';
export default PasswordResetForm;
